import { foundationNotificationListenerShadowOptions, foundationNotificationListenerTemplate, NotificationListener, } from '@genesislcap/foundation-ui';
import { logger } from '../utils';
const InteropNotificationSeverityMap = {
    Critical: 'error',
    High: 'warning',
    Medium: 'success',
};
const mapNotificationTypeToInteropSeverity = (type) => {
    return InteropNotificationSeverityMap[type];
};
/**
 * @tagname %%prefix%%-interop-notification-listener
 * @public
 * @remarks
 * This component extends the notification listener class and overrides the logic for showing the toast message to instead dispatch the event to the interop notifications bus.
 */
export class InteropNotificationsListener extends NotificationListener {
    showNotificationToast(row) {
        var _a, _b;
        const { HEADER: title, MESSAGE: body, NOTIFY_SEVERITY: type } = row;
        const severity = mapNotificationTypeToInteropSeverity(type === null || type === void 0 ? void 0 : type.toLowerCase());
        if ((_b = (_a = window.io) === null || _a === void 0 ? void 0 : _a.notifications) === null || _b === void 0 ? void 0 : _b.raise) {
            window.io.notifications.raise(Object.assign(Object.assign({}, this.iOConnectNotificationOptions), { title,
                body,
                severity, timestamp: row.CREATED_AT }));
        }
        else {
            logger.warn('Interop IO.notifications is not defined');
        }
    }
}
/**
 * The Foundation Interop Notification Listener
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-interop-notification-listener\>
 */
export const interopFoundationNotificationListener = InteropNotificationsListener.compose({
    baseName: 'interop-notification-listener',
    template: foundationNotificationListenerTemplate,
    shadowOptions: foundationNotificationListenerShadowOptions,
});
